@@ -13,8 +13,20 @@
 #'   calculations.
 #' @param calculations One or more summary calculations to use to calculate the
 #'   values of the cells in the pivot table.
-#' @param ... Additional arguments, currently format, formats, totals and/or
-#'   argumentCheckMode.
+#' @param theme Either the name of a built-in theme (default, largeplain,
+#'   compact or blank/none) or a list which specifies the default formatting for
+#'   the table.
+#' @param replaceExistingStyles TRUE to completely replace the default styling
+#'   with the specified tableStyle, headingStyle, cellStyle and/or totalStyle
+#' @param tableStyle A list of CSS style declarations that apply to the table.
+#' @param headingStyle A list of CSS style declarations that apply to the
+#'   heading cells in the table.
+#' @param cellStyle A list of CSS style declarations that apply to the normal
+#'   cells in the table.
+#' @param totalStyle A list of CSS style declarations that apply to the total
+#'   cells in the table.
+#' @param ... Additional arguments, currently format, formats, totals,
+#'   compatibility and/or argumentCheckMode.
 #' @return A pivot table.
 #' @examples
 #' qpvt(bhmtrains, "TOC", "TrainCategory", "n()")
@@ -22,21 +34,33 @@
 #'      c("Number of Trains"="n()",
 #'        "Maximum Speed"="max(SchedSpeedMPH, na.rm=TRUE)"))
 
-qpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
+qpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL,
+                 theme=NULL, replaceExistingStyles=FALSE,
+                 tableStyle=NULL, headingStyle=NULL, cellStyle=NULL, totalStyle=NULL, ...) {
   arguments <- list(...)
   checkArgument(3, TRUE, "", "qpvt", dataFrame, missing(dataFrame), allowMissing=FALSE, allowNull=FALSE, allowedClasses="data.frame")
   checkArgument(3, TRUE, "", "qpvt", rows, missing(rows), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
   checkArgument(3, TRUE, "", "qpvt", columns, missing(columns), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
   checkArgument(3, TRUE, "", "qpvt", calculations, missing(calculations), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
+  checkArgument(3, TRUE, "", "qpvt", theme, missing(theme), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyles"), allowedListElementClasses="character")
+  checkArgument(3, TRUE, "", "qpvt", replaceExistingStyles, missing(replaceExistingStyles), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
+  checkArgument(3, TRUE, "", "qpvt", tableStyle, missing(tableStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qpvt", headingStyle, missing(headingStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qpvt", cellStyle, missing(cellStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qpvt", totalStyle, missing(totalStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
   argumentCheckMode <- arguments$argumentCheckMode
   if(is.null(argumentCheckMode)) argumentCheckMode <- "auto"
+  compatibility <- arguments$compatibility
   dataName <- deparse(substitute(dataFrame))
   pt <- buildPivot(functionName="qpvt", argumentCheckMode=argumentCheckMode,
                    dataFrame=dataFrame, dataName=dataName,
                    rows=rows, columns=columns, calculations=calculations,
                    format=arguments[["format"]], formats=arguments[["formats"]], # can't use $format as this also matches formats
                    totalsSpecified=("totals" %in% names(arguments)),
-                   totals=arguments[["totals"]])
+                   totals=arguments[["totals"]],
+                   theme=theme, replaceExistingStyles=replaceExistingStyles,
+                   tableStyle=tableStyle, headingStyle=headingStyle, cellStyle=cellStyle, totalStyle=totalStyle,
+                   compatibility=compatibility)
   pt$evaluatePivot()
   return(pt)
 }
@@ -56,8 +80,20 @@ qpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
 #'   calculations.
 #' @param calculations One or more summary calculations to use to calculate the
 #'   values of the cells in the pivot table.
-#' @param ... Additional arguments, currently format, formats, totals and/or
-#'   argumentCheckMode.
+#' @param theme Either the name of a built-in theme (default, largeplain,
+#'   compact or blank/none) or a list which specifies the default formatting for
+#'   the table.
+#' @param replaceExistingStyles TRUE to completely replace the default styling
+#'   with the specified tableStyle, headingStyle, cellStyle and/or totalStyle
+#' @param tableStyle A list of CSS style declarations that apply to the table.
+#' @param headingStyle A list of CSS style declarations that apply to the
+#'   heading cells in the table.
+#' @param cellStyle A list of CSS style declarations that apply to the normal
+#'   cells in the table.
+#' @param totalStyle A list of CSS style declarations that apply to the total
+#'   cells in the table.
+#' @param ... Additional arguments, currently format, formats, totals,
+#'   styleNamePrefix, compatibility and/or argumentCheckMode.
 #' @return A HTML widget.
 #' @examples
 #' qhpvt(bhmtrains, "TOC", "TrainCategory", "n()")
@@ -68,22 +104,35 @@ qpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
 #'      totals=list("TOC"="All TOCs",
 #'        "TrainCategory"="All Categories"))
 
-qhpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
+qhpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL,
+                  theme=NULL, replaceExistingStyles=FALSE,
+                  tableStyle=NULL, headingStyle=NULL, cellStyle=NULL, totalStyle=NULL, ...) {
   arguments <- list(...)
   checkArgument(3, TRUE, "", "qhpvt", dataFrame, missing(dataFrame), allowMissing=FALSE, allowNull=FALSE, allowedClasses="data.frame")
   checkArgument(3, TRUE, "", "qhpvt", rows, missing(rows), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
   checkArgument(3, TRUE, "", "qhpvt", columns, missing(columns), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
   checkArgument(3, TRUE, "", "qhpvt", calculations, missing(calculations), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
+  checkArgument(3, TRUE, "", "qhpvt", theme, missing(theme), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyles"), allowedListElementClasses="character")
+  checkArgument(3, TRUE, "", "qhpvt", replaceExistingStyles, missing(replaceExistingStyles), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
+  checkArgument(3, TRUE, "", "qhpvt", tableStyle, missing(tableStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qhpvt", headingStyle, missing(headingStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qhpvt", cellStyle, missing(cellStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
+  checkArgument(3, TRUE, "", "qhpvt", totalStyle, missing(totalStyle), allowMissing=TRUE, allowNull=TRUE, allowedClasses=c("character", "list", "PivotStyle"))
   argumentCheckMode <- arguments$argumentCheckMode
   if(is.null(argumentCheckMode)) argumentCheckMode <- "auto"
+  compatibility <- arguments$compatibility
+  styleNamePrefix <- arguments$styleNamePrefix
   dataName <- deparse(substitute(dataFrame))
   pt <- buildPivot(functionName="qhpvt", argumentCheckMode=argumentCheckMode,
                    dataFrame=dataFrame, dataName=dataName,
                    rows=rows, columns=columns, calculations=calculations,
                    format=arguments[["format"]], formats=arguments[["formats"]], # can't use $format as this also matches formats
                    totalsSpecified=("totals" %in% names(arguments)),
-                   totals=arguments[["totals"]])
-  w <- pt$renderPivot()
+                   totals=arguments[["totals"]],
+                   theme=theme, replaceExistingStyles=replaceExistingStyles,
+                   tableStyle=tableStyle, headingStyle=headingStyle, cellStyle=cellStyle, totalStyle=totalStyle,
+                   compatibility=compatibility)
+  w <- pt$renderPivot(styleNamePrefix=styleNamePrefix)
   return(w)
 }
 
@@ -103,8 +152,8 @@ qhpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
 #' @param calculations One or more summary calculations to use to calculate the
 #'   values of the cells in the pivot table.
 #' @param ... Additional arguments, currently format, formats, totals,
-#'   argumentCheckMode, caption and/or label.  See the Latex output vignette for
-#'   a description of caption and label.
+#'   argumentCheckMode, compatibility, caption and/or label.  See the Latex
+#'   output vignette for a description of caption and label.
 #' @return Latex.
 #' @examples
 #' qlpvt(bhmtrains, "TOC", "TrainCategory", "n()")
@@ -119,13 +168,15 @@ qlpvt <- function(dataFrame, rows=NULL, columns=NULL, calculations=NULL, ...) {
   checkArgument(3, TRUE, "", "qlpvt", calculations, missing(calculations), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
   argumentCheckMode <- arguments$argumentCheckMode
   if(is.null(argumentCheckMode)) argumentCheckMode <- "auto"
+  compatibility <- arguments$compatibility
   dataName <- deparse(substitute(dataFrame))
   pt <- buildPivot(functionName="qlpvt", argumentCheckMode=argumentCheckMode,
                    dataFrame=dataFrame, dataName=dataName,
                    rows=rows, columns=columns, calculations=calculations,
                    format=arguments[["format"]], formats=arguments[["formats"]], # can't use $format as this also matches formats
                    totalsSpecified=("totals" %in% names(arguments)),
-                   totals=arguments[["totals"]])
+                   totals=arguments[["totals"]],
+                   compatibility=compatibility)
   return(pt$getLatex(caption=arguments$caption, label=arguments$label))
 }
 
@@ -156,13 +207,16 @@ buildPivot <- function(functionName=NULL, argumentCheckMode=NULL,
                        dataFrame=NULL, dataName=NULL,
                        rows=NULL, columns=NULL, calculations=NULL,
                        format=NULL, formats=NULL,
-                       totalsSpecified=FALSE, totals=NULL) {
+                       totalsSpecified=FALSE, totals=NULL,
+                       theme=NULL, replaceExistingStyles=FALSE,
+                       tableStyle=NULL, headingStyle=NULL, cellStyle=NULL, totalStyle=NULL,
+                       compatibility=compatibility) {
   if(is.null(dataFrame)) stop(paste0(functionName, "():  dataFrame argument must not be NULL."), call. = FALSE)
   if(!is.data.frame(dataFrame)) stop(paste0(functionName, "():  dataFrame argument must be a data frame."), call. = FALSE)
-  if((!is.null(rows))&&(!is.na(rows))) {
+  if((!is.null(rows))&&(!anyNA(rows))) {
     if(!is.character(rows)) stop(paste0(functionName, "():  rows must be a character vector."), call. = FALSE)
   }
-  if((!is.null(columns))&&(!is.na(columns))) {
+  if((!is.null(columns))&&(!anyNA(columns))) {
     if(!is.character(columns)) stop(paste0(functionName, "():  columns must be a character vector."), call. = FALSE)
   }
   if((length(rows[rows=="="])+length(columns[columns=="="]))>1) {
@@ -187,10 +241,12 @@ buildPivot <- function(functionName=NULL, argumentCheckMode=NULL,
       stop(paste0(functionName, "():  totals must be a character vector."), call. = FALSE)
     }
   }
-  pt <- PivotTable$new(argumentCheckMode=argumentCheckMode)
+  pt <- PivotTable$new(argumentCheckMode=argumentCheckMode, theme=theme, replaceExistingStyles=replaceExistingStyles,
+                       tableStyle=tableStyle, headingStyle=headingStyle, cellStyle=cellStyle, totalStyle=totalStyle,
+                       compatibility=compatibility)
   pt$addData(dataFrame, dataName=dataName)
   bCalculationsAdded <- FALSE
-  if((!is.null(rows))&&(!is.na(rows))) {
+  if((!is.null(rows))&&(!anyNA(rows))) {
     for(i in 1:length(rows)) {
       if(rows[i]=="=") {
         if(bCalculationsAdded==TRUE) stop(paste0(functionName, "():  Calculations cannot be added more than once."), call. = FALSE)
@@ -211,7 +267,7 @@ buildPivot <- function(functionName=NULL, argumentCheckMode=NULL,
       }
     }
   }
-  if((!is.null(columns))&&(!is.na(columns))) {
+  if((!is.null(columns))&&(!anyNA(columns))) {
     for(i in 1:length(columns)) {
       if(columns[i]=="=") {
         if(bCalculationsAdded==TRUE) stop(paste0(functionName, "():  Calculations cannot be added more than once."), call. = FALSE)
